<div id="header" align="center">
    <img src="https://github.com/romanin-rf/SeaPlayer/assets/60302782/937adcc4-f547-440c-8139-a5f15bffa157" alt="Icon" width="300">
</div>
<div id="header" align="center"><h1>SeaPlayer</h1></div>

## Descriptions
SeaPlayer is a player that works in the terminal. Works with `MP3`, `OGG`, `WAV`, `MIDI` and `FLAC` files.

## Install


1. You can use [Release](https://github.com/romanin-rf/sea-player/releases)
2. ***Download clone repository*** install the dependencies from `requirements.txt` and run via [Python](https://www.python.org).
3.  ```
    pip install --upgrade seaplayer
    ```

### For MIDI playback
***If you have Windows*** you can skip this part as ***Windows*** has a default decoder for `MIDI` and ***does not need to be installed***.


***For Linux or MacOS users:***

You need to [install the FluidSynth](https://github.com/FluidSynth/fluidsynth/wiki/Download) package in order to playback `MIDI`.

## Using
```shell
python -m seaplayer # Method for `downloaded repository` or `installed via pip`
```

![MainScreen-v0.4.3.dev1](https://github.com/romanin-rf/SeaPlayer/assets/60302782/e4b2ee2c-9061-47ff-8818-a480b3a79a5e)
![ConfigurateScreen-v0.4.3.dev1](https://github.com/romanin-rf/SeaPlayer/assets/60302782/ad84eafb-2324-4036-81c3-81df9138025a)
